// -------------------------------------------------------------------------------
//
//    This is a Template used as a guideline to build your own Robot. 
//    Please use the “Feedback” tab to provide us with your suggestions about cAlgo’s API.
//
// -------------------------------------------------------------------------------

using System;
using cAlgo.API;
using cAlgo.API.Indicators;

namespace cAlgo.Robots
{
    [Robot]
    public class NewRobot : Robot
    {
        [Parameter("Vol", DefaultValue = 10000)]
        public int Vol { get; set; }
        
        [Parameter("TP", DefaultValue = 200)]
        public int TP { get; set; }
        
        [Parameter("SL", DefaultValue = 200)]
        public int SL { get; set; }
        
        [Parameter("MA_price")]
        public DataSeries MA_price { get; set; }
        
        [Parameter("MA_period", DefaultValue = 20)]
        public int MA_period { get; set; }
        
        [Parameter("MAType")]
        public MovingAverageType MAType { get; set; }
        
        [Parameter("MO_price")]
        public DataSeries MO_price { get; set; }
        
        [Parameter("MO_period", DefaultValue = 5)]
        public int MO_period { get; set; }
                
        [Parameter("Tral_Start", DefaultValue = 150)]
        public int Tral_Start { get; set; }
        
        [Parameter("Tral_Stop", DefaultValue = 100)]
        public int Tral_Stop { get; set; }
        
        [Parameter("Open_Buy", DefaultValue = 1)]
        public int Open_Buy { get; set; }
        
        [Parameter("Open_Sell", DefaultValue = 1)]
        public int Open_Sell { get; set; }
                
        
        private MovingAverage MA; 
        private MomentumOscillator MO;
        private int a;
        private Position position1,pos1;
        
        
        protected override void OnStart()
        {
        Print("Welcome to the world of infinite financial possibilities!");
        
        MO= Indicators.MomentumOscillator(MO_price,MO_period);
        MA= Indicators.MovingAverage(MA_price, MA_period, MAType);
        
        }
        
         protected override void OnPositionOpened(Position openedPosition)
        {
            position1 = openedPosition;
            double Point=Symbol.PointSize;

            if (position1.TradeType == TradeType.Buy)
            Trade.ModifyPosition(openedPosition, position1.EntryPrice-SL*Point, position1.EntryPrice+TP*Point);
            
            if (position1.TradeType == TradeType.Sell)
            Trade.ModifyPosition(openedPosition, position1.EntryPrice+SL*Point, position1.EntryPrice-TP*Point);
        }
        
  

        protected override void OnTick()
        {
        
        double Bid=Symbol.Bid;
        double Ask=Symbol.Ask;
        double Point=Symbol.PointSize;
        
        double MO1=MO.Result[MO.Result.Count-2];
        double MA1=MA.Result[MA.Result.Count-2];
        
        int bars=MarketSeries.Close.Count-1;
        double cl=MarketSeries.Close[bars-1];
        
       foreach (var position in Account.Positions)
            {
            	if(position.SymbolCode == Symbol.Code)
            	{
            	
            		if(position.TradeType == TradeType.Buy)	
            		{
            		if (Bid-position.EntryPrice>=Tral_Start*Point)
            		if (Bid-Tral_Stop*Point>=position.StopLoss)
            		Trade.ModifyPosition(position, Bid-Tral_Stop*Point, position.TakeProfit);
            		}
            			
            		if(position.TradeType == TradeType.Sell)	
            		{
            		if (position.EntryPrice-Ask>=Tral_Start*Point)
            		if (Ask+Tral_Stop*Point<=position.StopLoss)
            		Trade.ModifyPosition(position, Ask+Tral_Stop*Point, position.TakeProfit);
            		}
            		
            		if(position.TradeType == TradeType.Buy)	
            		{
            		if (cl<MA1)
            		Trade.Close(position);
            		}
            			
            		if(position.TradeType == TradeType.Sell)	
            		{
            		if (cl>MA1)
            		Trade.Close(position);
            		}
            	}
             }            	
            			
            			
          if (Trade.IsExecuting) return;

          if (MA1>cl && MO1<100 && a==0 && Open_Sell==1)
          {
          Trade.CreateSellMarketOrder(Symbol, Vol);
          a=1;
          }
          
          if (MA1<cl && MO1>100 && a==0 && Open_Buy==1)
          {
          Trade.CreateBuyMarketOrder(Symbol, Vol);
          a=1;
          }			      
        }
        
         
         protected override void OnPositionClosed(Position pos)
         {
          a=0;
         }
         
        protected override void OnStop()
        {
         Print("Successful day!");
        }
    }
}